@@ -268,7 +268,16 @@ class Attachment(Errorable):
 
     def __eq__(self, other):
         if isinstance(other, self.__class__):
-            return self.pb == other.pb
+            for field in self.pb.DESCRIPTOR.fields:
+                self_field_value = getattr(self.pb, field.name)
+                other_field_value = getattr(other.pb, field.name)
+                if field.label == field.LABEL_REPEATED:  # compare lists as sets
+                    if set(self_field_value) != set(other_field_value):
+                        return False
+                else:
+                    if self_field_value != other_field_value:
+                        return False
+            return True
         return False
 
 
